{% extends 'wagtailadmin/reports/base_report.html' %} {% load i18n wagtailadmin_tags %} {% block titletag %}{% blocktrans trimmed with title=subtitle %}Page history for {{ subtitle }}{% endblocktrans %}{% endblock %} {% block actions %} {% icon name="edit" wrapped=1 %}{% trans "Edit this page" %} {% endblock %} {% block results %} {% if object_list %}

{% trans 'Action' %} | {% trans 'User' %} | {% trans 'Date / Time' %}
--- | --- | ---
{% page_permissions page as page_perms %} {% for entry in object_list %}
{% if entry.revision %}{% endif %} {{ entry.message }} {% if entry.revision %}{% endif %} {% if entry.comment %} {% trans "Comment" %}: {{ entry.comment }} {% endif %} {% if entry.revision %} {% if entry.action == 'wagtail.publish' %} {% if entry.revision_id == page.live_revision_id %}{% trans 'Live version' as status_label %}{% status status_label classname="w-status--primary" %}{% endif %} {% elif entry.content_changed %} {% if entry.revision == page_latest_revision %}{% trans 'Current draft' as status_label %}{% status status_label classname="w-status--primary" %}{% endif %} {% include "wagtailadmin/pages/revisions/_actions.html" with revision=entry.revision %} {% endif %} {% endif %} | {% include "wagtailadmin/shared/user_avatar.html" with user=entry.user username=entry.user_display_name %} | {% human_readable_date entry.timestamp %}
{% endfor %}

{% else %}

{% trans "No log entries found." %}

{% endif %} {% endblock %} {% block no_results %}

{% trans "No log entries found." %}

{% endblock %}